[−][src]Function glsp_engine::arr_from_elem
pub fn arr_from_elem<T: ToVal>(elem: T, reps: usize) -> GResult<Root<Arr>>
Constructs an array which contains reps repetitions of elem.
Returns an Err if type conversion fails.
pub fn arr_from_elem<T: ToVal>(elem: T, reps: usize) -> GResult<Root<Arr>>
Constructs an array which contains reps repetitions of elem.
Returns an Err if type conversion fails.