[−][src]Function glsp_engine::rdata
pub fn rdata<T: RStore>(rdata: T) -> GResult<Root<RData>>
Moves a Rust value onto the garbage-collected heap.
Rust types are automatically registered with the Runtime when glsp::rdata is first called
for a value of that type. If two types share the same unprefixed name, like
video::Clip and audio::Clip, it's an error.