[−][src]Macro glsp_engine::str
Constructs a string.
The syntax is similar to the format! macro. str!("hello, {}", x) will return a
newly-allocated Root<Str>, with the text representation of x printed into it.
Constructs a string.
The syntax is similar to the format! macro. str!("hello, {}", x) will return a
newly-allocated Root<Str>, with the text representation of x printed into it.