[−][src]Struct glsp_engine::RFn
The rfn primitive type.
Rust functions are represented by a small Copy type (a 32-bit integer id).
Most of this type's methods belong to the callable abstract type, so they can be found in
the CallableOps trait. To invoke an RFn, use
glsp::call.
To convert a function pointer or a closure into an RFn, you should usually call
glsp::bind_rfn or glsp::rfn.