[−][src]Struct glsp_engine::TabEntries
An adapter struct which can be used to iterate over the contents of a table.
Created by Tab::entries.
Implementations
impl<'a> TabEntries<'a>[src]
pub fn iter<'b>(&'b self) -> IterTab<'a, 'b>[src]
Creates an infallible iterator over this table's (key, value) pairs.
The iterator's item type will be (Val, Val).
pub fn iter_to<'b, K: FromVal, V: FromVal>(&'b self) -> IterTabTo<'a, 'b, K, V>[src]
Creates a converting iterator over this table's (key, value) pairs.
The iterator can produce any tuple (K, V), where both K and V implement
FromVal. Each key/value pair will be wrapped as
GResult<(K, V)>, so it will need to be unwrapped using ?
before it can be used.
pub fn keys<'b>(&'b self) -> IterTabKeys<'a, 'b>[src]
Creates an infallible iterator over this table's keys.
The iterator's item type will be Val.
pub fn keys_to<'b, K: FromVal>(&'b self) -> IterTabKeysTo<'a, 'b, K>[src]
Creates a converting iterator over this table's keys.
The iterator can produce any type which implements FromVal.
Each key will be wrapped as a GResult<K>, so it will need to
be unwrapped using ? before it can be used.
pub fn values<'b>(&'b self) -> IterTabValues<'a, 'b>[src]
Creates an infallible iterator over this table's values.
The iterator's item type will be Val.
pub fn values_to<'b, V: FromVal>(&'b self) -> IterTabValuesTo<'a, 'b, V>[src]
Creates a converting iterator over this table's values.
The iterator can produce any type which implements FromVal.
Each key will be wrapped as a GResult<V>, so it will need to
be unwrapped using ? before it can be used.