[−][src]Trait glsp_engine::RStore
A type which can be moved onto the garbage-collected heap as an RData.
It's possible to implement this trait manually, but using the rdata! macro
is strongly encouraged. Among other things, that macro will automatically implement
MakeArg and IntoResult for your type.