[−][src]Function glsp_engine::take_lib
pub fn take_lib<T: Lib>() -> GResult<T>
Unregisters a value previously registered using glsp::add_lib, and
returns it.
Returns Err if no library is registered for the type T, or if a library exists but it's
currently borrowed.